wizard — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# wizard

The wizard module contains generic wizards and wizard pages

- backup
- importwizard
- merge_document
- new
- new_company
- pages
  - backup_page
  - form_page
  - progress_page
  - select
  - update_entities_page
- update_value

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus